@@ -1,6 +1,6 @@
 package App::perlmv::scriptlets::std;
 BEGIN {
-  $App::perlmv::scriptlets::std::VERSION = '0.40';
+  $App::perlmv::scriptlets::std::VERSION = '0.41';
 }
 # ABSTRACT: A collection of perlmv scriptlets
 
@@ -52,6 +52,14 @@ $_
 EOT
 
 
+$scriptlets{'to-number'} = <<'EOT';
+### Summary: Rename files into numbers. Ex: (file1.txt, foo.jpg, quux.mpg) -> (1, 2, 3)
+if ($COMPILING || $CLEANING) { $i=0 } else { $i++ }
+$ndig = @$FILES >= 1000 ? 4 : @$FILES >= 100 ? 3 : @$FILES >= 10 ? 2 : 1;
+sprintf "%0${ndig}d", $i
+EOT
+
+
 $scriptlets{'to-number-ext'} = <<'EOT';
 ### Summary: Rename files into numbers. Preserve extensions. Ex: (file1.txt, foo.jpg, quux.mpg) -> (1.txt, 2.jpg, 3.mpg)
 if ($COMPILING || $CLEANING) { $i=0 } else { $i++ }
@@ -61,6 +69,14 @@ sprintf "%0${ndig}d%s", $i, (defined($ext) ? ".$ext" : "")
 EOT
 
 
+$scriptlets{'to-timestamp'} = <<'EOT';
+### Summary: Rename files into timestamp. Ex: file1.txt -> 2010-05-13-10_43_49
+use POSIX;
+@st = lstat $_;
+POSIX::strftime("%Y-%m-%d-%H_%M_%S", localtime $st[9])
+EOT
+
+
 $scriptlets{'to-timestamp-ext'} = <<'EOT';
 ### Summary: Rename files into timestamp. Preserve extensions. Ex: file1.txt -> 2010-05-13-10_43_49.txt
 use POSIX; /.+\.(.+)/; $ext=$1;
@@ -94,7 +110,7 @@ App::perlmv::scriptlets::std - A collection of perlmv scriptlets
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SCRIPTLETS
 
@@ -118,11 +134,21 @@ Remove prefix that are common to all args, e.g. (file1, file2b) -> (1,
 Remove suffix that are common to all args, while preserving extension,
 e.g. (1-radiolab.mp3, 2-radiolab.mp3) -> (1.mp3, 2.mp3)
 
+=head2 to-number
+
+Rename files into numbers. Ex: (file1.txt, foo.jpg, quux.mpg) -> (1.txt, 2.jpg,
+3.mpg). See also: to-number-ext.
+
 =head2 to-number-ext
 
 Rename files into numbers. Preserve extensions. Ex: (file1.txt,
 foo.jpg, quux.mpg) -> (1.txt, 2.jpg, 3.mpg)
 
+=head2 to-timestamp
+
+Rename files into timestamp. Ex: file1.txt -> 2010-05-13-10_43_49. See also:
+to-timestamp-ext.
+
 =head2 to-timestamp-ext
 
 Rename files into timestamp. Preserve extensions. Ex: file1.txt ->
